package com.ghjg.pd.config;

import com.shanghaigeography.entity.ResultMsg;
import com.shanghaigeography.eum.ResultState;
import javax.naming.AuthenticationException;
import lombok.extern.slf4j.Slf4j;
import org.springframework.http.HttpStatus;
import org.springframework.validation.BindingResult;
import org.springframework.validation.ObjectError;
import org.springframework.web.bind.MethodArgumentNotValidException;
import org.springframework.web.bind.annotation.ExceptionHandler;
import org.springframework.web.bind.annotation.ResponseStatus;
import org.springframework.web.bind.annotation.RestControllerAdvice;


/**
 * 统一异常处理
 */
@Slf4j
@RestControllerAdvice
public class GlobalExceptionHandler {
    @ResponseStatus(HttpStatus.FORBIDDEN)
    @ExceptionHandler(value = AuthenticationException.class)
    public ResultMsg handler(AuthenticationException e) {
        log.info("security权限存在问题:----------------{}", e.getMessage());
        return new ResultMsg<String>().setCode(ResultState.ERROR).setMsg("权限存在问题");
    }

    @ResponseStatus(HttpStatus.BAD_REQUEST)
    @ExceptionHandler(value = MethodArgumentNotValidException.class)
    public ResultMsg handler(MethodArgumentNotValidException e) {
        BindingResult bindingResult = e.getBindingResult();
        ObjectError objectError = bindingResult.getAllErrors().stream().findFirst().get();
        log.info("实体校验异常:----------------{}",objectError.getDefaultMessage());
        return new ResultMsg<String>().setCode(ResultState.ERROR).setMsg(objectError.getDefaultMessage());
    }

    @ResponseStatus(HttpStatus.BAD_REQUEST)
    @ExceptionHandler(value = IllegalArgumentException.class)
    public ResultMsg handler(IllegalArgumentException e) {
        log.error("Assert异常:----------------{}", e.getMessage());
        return new ResultMsg<String>().setCode(ResultState.ERROR).setMsg(e.getMessage());
    }

//    @ResponseStatus(HttpStatus.BAD_REQUEST)
//    @ExceptionHandler(value = RuntimeException.class)
//    public ResultMsg handler(RuntimeException e) {
//        log.error("运行时异常:----------------{}", e.getMessage());
//        return new ResultMsg<String>().setCode(ResultState.ERROR).setMsg(e.getMessage());
//    }
}