package com.ghjg.pd.controller.ass;


import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.toolkit.CollectionUtils;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.ghjg.pd.config.SnowflakeMakeConf;
import com.ghjg.pd.controller.BaseController;
import com.ghjg.pd.controller.model.req.ass.AssPageDepartmentReq;
import com.ghjg.pd.controller.model.res.ass.AssPageDepartmentRes;
import com.ghjg.pd.entity.ass.AssPageDepartment;
import com.ghjg.pd.service.ass.AssPageDepartmentService;
import com.ghjg.pd.uitll.CommonTools;
import com.ghjg.pd.uitll.ReturnMsg;
import com.ghjg.pd.uitll.TokenUtil;
import com.shanghaigeography.Util.DateUtils;
import com.shanghaigeography.entity.ResultMsg;
import com.shanghaigeography.eum.ResultState;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.Parameter;
import io.swagger.v3.oas.annotations.tags.Tag;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.Map;
import java.util.Objects;
import javax.annotation.Resource;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;

/**
 * <p>
 * 部门和页面关系表 前端控制器
 * </p>
 *
 * @author zk
 * @since 2024-01-04
 */
@Controller
@RequestMapping("/fortrans/assPageDepartment")
@Tag(name = "部门和页面关系管理", description = "刘澳港")
public class AssPageDepartmentController extends BaseController {

  @Resource
  AssPageDepartmentService assPageDepartmentService;
  @Resource
  SnowflakeMakeConf snowflakeMakeConf;

  @PostMapping("/saveOrUpdate")
  @Operation(summary = "新增或修改部门和页面关系")
  public String saveOrUpdatePage(@RequestBody AssPageDepartmentReq req) {
    try {
      AssPageDepartment assPageDepartment = AssPageDepartment.from(req);
      if (Objects.isNull(assPageDepartment.getAssId())) {
        // 新增
        long id = snowflakeMakeConf.snowflakeId();
        assPageDepartment.setPageId(String.valueOf(id));
        assPageDepartment.setCreateTime(new Date());
        // todo 操作人员获取
//        sysUser.setCreateUser(TokenUtil.getLocalUser().getUserName());
        assPageDepartmentService.save(assPageDepartment);
      } else {
        // 修改
        assPageDepartment.setUpdateTime(new Date());
//        sysUser.setUpdateUser(TokenUtil.getLocalUser().getUserName());
        assPageDepartmentService.updateById(assPageDepartment);
      }
      //todo 授权相关操作
      return new ResultMsg<String>().setCode(ResultState.SUCCESS).setMsg("操作成功").setData(null)
          .toJSON();
    } catch (Exception e) {
      e.printStackTrace();
      return new ResultMsg<String>().setCode(ResultState.ERROR).setMsg("操作异常")
          .setData(e.getMessage()).toJSON();
    }
  }

  @DeleteMapping("/delete/{id}")
  @Operation(summary = "删除页面部门关系")
  public String deletePage(@PathVariable("id") String id) {
    try {
      AssPageDepartment assPageDepartment = assPageDepartmentService.getById(id);
      assPageDepartment.setDeleteFlag(1);
      assPageDepartment.setUpdateTime(new Date());
      assPageDepartment.setUpdateUser(TokenUtil.getLocalUser().getUserName());
      assPageDepartmentService.updateById(assPageDepartment);
      return new ResultMsg<String>().setCode(ResultState.SUCCESS).setMsg("删除成功").setData(null)
          .toJSON();
    } catch (Exception e) {
      return new ResultMsg<String>().setCode(ResultState.ERROR).setMsg("删除失败")
          .setData(e.getMessage())
          .toJSON();
    }
  }

  @PostMapping("/list")
  @Operation(summary = "获取页面部门关系列表")
  @Parameter(description = "current,size,departmentId,pageId")
  public String getList(@RequestBody Map<String, Object> request) {
    int current = (int) request.get("current");
    List<AssPageDepartment> list = assPageDepartmentService.getList(request);
    if (CollectionUtils.isEmpty(list)) {
      return new ResultMsg<String>().setCode(ResultState.ERROR_NEEDDATA).setMsg("暂无数据")
          .setData(null)
          .toJSON();
    }
    int count = CommonTools.getTotal(list);
    List<AssPageDepartmentRes> resList = new ArrayList<>(list.size());
    list.forEach(x -> {
      AssPageDepartmentRes from = AssPageDepartmentRes.from(x);
      resList.add(from);
    });
    return ReturnMsg.returnMsgForList("_200",
        JSONArray.parseArray(
            JSONArray.toJSONStringWithDateFormat(resList, DateUtils.DATE_FORMAT_19)),
        count, current);
  }


  @GetMapping("/detail/{id}")
  @Operation(summary = "获取页面部门关系信息")
  public String getSysPageById(@PathVariable("id") String id) {
    try {
      AssPageDepartment one = assPageDepartmentService.getOne(
          Wrappers.<AssPageDepartment>lambdaQuery().eq(AssPageDepartment::getAssId, id));
      return new ResultMsg<String>().setCode(ResultState.SUCCESS)
          .setData(JSONObject.toJSONString(AssPageDepartmentRes.from(one)))
          .toJSON();
    } catch (Exception e) {
      return new ResultMsg<String>().setCode(ResultState.ERROR_NEEDDATA).setMsg("暂无数据")
          .setData(e.getMessage())
          .toJSON();
    }
  }
}
