package com.ghjg.pd.controller.ass;


import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.toolkit.CollectionUtils;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.ghjg.pd.config.SnowflakeMakeConf;
import com.ghjg.pd.controller.BaseController;
import com.ghjg.pd.controller.model.req.ass.AssPageRoleReq;
import com.ghjg.pd.controller.model.res.ass.AssPageRoleRes;
import com.ghjg.pd.entity.ass.AssPageRole;
import com.ghjg.pd.service.ass.AssPageRoleService;
import com.ghjg.pd.uitll.CommonTools;
import com.ghjg.pd.uitll.ReturnMsg;
import com.ghjg.pd.uitll.TokenUtil;
import com.shanghaigeography.Util.DateUtils;
import com.shanghaigeography.entity.ResultMsg;
import com.shanghaigeography.eum.ResultState;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.Parameter;
import io.swagger.v3.oas.annotations.tags.Tag;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.Map;
import java.util.Objects;
import javax.annotation.Resource;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;

/**
 * <p>
 * 角色和页面表 前端控制器
 * </p>
 *
 * @author zk
 * @since 2024-01-04
 */
@Controller
@RequestMapping("/fortrans/assPageRole")
@Tag(name = "角色页面对应表管理", description = "刘澳港")
public class AssPageRoleController extends BaseController {

  @Resource
  AssPageRoleService assPageRoleService;

  @Resource
  SnowflakeMakeConf snowflakeMakeConf;

  @PostMapping("/saveOrUpdate")
  @Operation(summary = "新增或修改角色页面对应表")
  public String saveOrUpdateAssPageRole(@RequestBody AssPageRoleReq req) {
    try {
      AssPageRole assPageRole = AssPageRole.from(req);
      if (Objects.isNull(assPageRole.getAssId())) {
        // 新增
        long id = snowflakeMakeConf.snowflakeId();
        assPageRole.setPageId(String.valueOf(id));
        assPageRole.setCreateTime(new Date());
        // todo 操作人员获取
//        sysUser.setCreateUser(TokenUtil.getLocalUser().getUserName());
        assPageRoleService.save(assPageRole);
      } else {
        // 修改
        assPageRole.setUpdateTime(new Date());
//        sysUser.setUpdateUser(TokenUtil.getLocalUser().getUserName());
        assPageRoleService.updateById(assPageRole);
      }
      //todo 授权相关操作
      return new ResultMsg<String>().setCode(ResultState.SUCCESS).setMsg("操作成功").setData(null)
          .toJSON();
    } catch (Exception e) {
      e.printStackTrace();
      return new ResultMsg<String>().setCode(ResultState.ERROR).setMsg("操作异常")
          .setData(e.getMessage()).toJSON();
    }
  }

  @DeleteMapping("/delete/{id}")
  @Operation(summary = "删除角色页面对应表")
  public String deletePage(@PathVariable("id") String id) {
    try {
      AssPageRole assPageRole = assPageRoleService.getById(id);
      assPageRole.setDeleteFlag(1);
      assPageRole.setUpdateTime(new Date());
      assPageRole.setUpdateUser(TokenUtil.getLocalUser().getUserName());
      assPageRoleService.updateById(assPageRole);
      return new ResultMsg<String>().setCode(ResultState.SUCCESS).setMsg("删除成功").setData(null)
          .toJSON();
    } catch (Exception e) {
      return new ResultMsg<String>().setCode(ResultState.ERROR).setMsg("删除失败")
          .setData(e.getMessage())
          .toJSON();
    }
  }

  @PostMapping("/list")
  @Operation(summary = "获取角色页面对应表")
  @Parameter(description = "current,size,roleId,pageId")
  public String getList(@RequestBody Map<String, Object> request) {
    int current = (int) request.get("current");
    List<AssPageRole> list = assPageRoleService.getList(request);
    if (CollectionUtils.isEmpty(list)) {
      return new ResultMsg<String>().setCode(ResultState.ERROR_NEEDDATA).setMsg("暂无数据")
          .setData(null)
          .toJSON();
    }
    int count = CommonTools.getTotal(list);
    List<AssPageRoleRes> resList = new ArrayList<>(list.size());
    list.forEach(x -> {
      AssPageRoleRes from = AssPageRoleRes.from(x);
      resList.add(from);
    });
    return ReturnMsg.returnMsgForList("_200",
        JSONArray.parseArray(
            JSONArray.toJSONStringWithDateFormat(resList, DateUtils.DATE_FORMAT_19)),
        count, current);
  }


  @GetMapping("/detail/{id}")
  @Operation(summary = "获取角色页面对应表信息")
  public String getSysPageById(@PathVariable("id") String id) {
    try {
      AssPageRole one = assPageRoleService.getOne(
          Wrappers.<AssPageRole>lambdaQuery().eq(AssPageRole::getAssId, id));
      return new ResultMsg<String>().setCode(ResultState.SUCCESS)
          .setData(JSONObject.toJSONString(AssPageRoleRes.from(one)))
          .toJSON();
    } catch (Exception e) {
      return new ResultMsg<String>().setCode(ResultState.ERROR_NEEDDATA).setMsg("暂无数据")
          .setData(e.getMessage())
          .toJSON();
    }
  }
}
