package com.ghjg.pd.controller.ass;


import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.toolkit.CollectionUtils;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.ghjg.pd.config.SnowflakeMakeConf;
import com.ghjg.pd.controller.BaseController;
import com.ghjg.pd.controller.model.req.ass.AssUserRoleReq;
import com.ghjg.pd.controller.model.res.ass.AssUserRoleRes;
import com.ghjg.pd.entity.ass.AssUserRole;
import com.ghjg.pd.service.ass.AssUserRoleService;
import com.ghjg.pd.uitll.CommonTools;
import com.ghjg.pd.uitll.ReturnMsg;
import com.ghjg.pd.uitll.TokenUtil;
import com.shanghaigeography.Util.DateUtils;
import com.shanghaigeography.entity.ResultMsg;
import com.shanghaigeography.eum.ResultState;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.Parameter;
import io.swagger.v3.oas.annotations.tags.Tag;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.Map;
import java.util.Objects;
import javax.annotation.Resource;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;

/**
 * <p>
 * 用户角色表 前端控制器
 * </p>
 *
 * @author zk
 * @since 2024-01-04
 */
@Controller
@RequestMapping("/fortrans/assUserRole")
@Tag(name = "用户角色对应表管理", description = "刘澳港")
public class AssUserRoleController extends BaseController {

  @Resource
  AssUserRoleService assUserRoleService;

  @Resource
  SnowflakeMakeConf snowflakeMakeConf;

  @PostMapping("/saveOrUpdate")
  @Operation(summary = "新增或修改用户角色对应表")
  public String saveOrUpdateAssUserRole(@RequestBody AssUserRoleReq req) {
    try {
      AssUserRole assUserRole = AssUserRole.from(req);
      if (Objects.isNull(assUserRole.getAssId())) {
        // 新增
        long id = snowflakeMakeConf.snowflakeId();
        assUserRole.setAssId(String.valueOf(id));
        assUserRole.setCreateTime(new Date());
        // todo 操作人员获取
//        sysUser.setCreateUser(TokenUtil.getLocalUser().getUserName());
        assUserRoleService.save(assUserRole);
      } else {
        // 修改
        assUserRole.setUpdateTime(new Date());
//        sysUser.setUpdateUser(TokenUtil.getLocalUser().getUserName());
        assUserRoleService.updateById(assUserRole);
      }
      //todo 授权相关操作
      return new ResultMsg<String>().setCode(ResultState.SUCCESS).setMsg("操作成功").setData(null)
          .toJSON();
    } catch (Exception e) {
      e.printStackTrace();
      return new ResultMsg<String>().setCode(ResultState.ERROR).setMsg("操作异常")
          .setData(e.getMessage()).toJSON();
    }
  }

  @DeleteMapping("/delete/{id}")
  @Operation(summary = "删除用户角色对应表")
  public String deletePage(@PathVariable("id") String id) {
    try {
      AssUserRole assUserRole = assUserRoleService.getById(id);
      assUserRole.setDeleteFlag(1);
      assUserRole.setUpdateTime(new Date());
      assUserRole.setUpdateUser(TokenUtil.getLocalUser().getUserName());
      assUserRoleService.updateById(assUserRole);
      return new ResultMsg<String>().setCode(ResultState.SUCCESS).setMsg("删除成功").setData(null)
          .toJSON();
    } catch (Exception e) {
      return new ResultMsg<String>().setCode(ResultState.ERROR).setMsg("删除失败")
          .setData(e.getMessage())
          .toJSON();
    }
  }

  @PostMapping("/list")
  @Parameter(description = "current,size,userId,roleId")
  @Operation(summary = "获取角色页面对应表")
  public String getList(@RequestBody Map<String, Object> request) {
    int current = (int) request.get("current");
    List<AssUserRole> list = assUserRoleService.getList(request);
    if (CollectionUtils.isEmpty(list)) {
      return new ResultMsg<String>().setCode(ResultState.ERROR_NEEDDATA).setMsg("暂无数据")
          .setData(null)
          .toJSON();
    }
    int count = CommonTools.getTotal(list);
    List<AssUserRoleRes> resList = new ArrayList<>(list.size());
    list.forEach(x -> {
      AssUserRoleRes from = AssUserRoleRes.from(x);
      resList.add(from);
    });
    return ReturnMsg.returnMsgForList("_200",
        JSONArray.parseArray(
            JSONArray.toJSONStringWithDateFormat(resList, DateUtils.DATE_FORMAT_19)),
        count, current);
  }


  @GetMapping("/detail/{id}")
  @Operation(summary = "获取角色页面对应表信息")
  public String getSysPageById(@PathVariable("id") String id) {
    try {
      AssUserRole one = assUserRoleService.getOne(
          Wrappers.<AssUserRole>lambdaQuery().eq(AssUserRole::getAssId, id));
      return new ResultMsg<String>().setCode(ResultState.SUCCESS)
          .setData(JSONObject.toJSONString(AssUserRoleRes.from(one)))
          .toJSON();
    } catch (Exception e) {
      return new ResultMsg<String>().setCode(ResultState.ERROR_NEEDDATA).setMsg("暂无数据")
          .setData(e.getMessage())
          .toJSON();
    }
  }
}
