package com.ghjg.pd.controller.login;

import com.alibaba.fastjson.JSONObject;
import com.ghjg.pd.controller.model.res.sys.SysUserRes;
import com.ghjg.pd.entity.sys.SysUser;
import com.ghjg.pd.uitll.TokenUtil;
import com.shanghaigeography.entity.ResultMsg;
import com.shanghaigeography.eum.ResultState;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.Parameter;
import io.swagger.v3.oas.annotations.tags.Tag;
import java.util.Map;
import lombok.extern.slf4j.Slf4j;
import org.apache.shiro.SecurityUtils;
import org.apache.shiro.authc.UsernamePasswordToken;
import org.apache.shiro.subject.Subject;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

@RestController
@Slf4j
@RequestMapping
@Tag(name = "登录相关", description = "刘澳港")
public class LoginController {


  @PostMapping(value = "/login")
  @Operation(summary = "登录")
  @Parameter(description = "username,password")
  public String login(@RequestBody Map<String, String> map) {

    try {
      Subject subject = SecurityUtils.getSubject();
      String username = map.get("username");
      String password = map.get("password");
      String token = TokenUtil.getToken(username, password, "23113113212");
      subject.login(new UsernamePasswordToken(username, password, false));
      return new ResultMsg<String>().setCode(ResultState.SUCCESS).setData(token).toJSON();
    } catch (Exception e) {
      return new ResultMsg<String>().setCode(ResultState.ERROR).setMsg(e.getMessage()).setData(null)
          .toJSON();
    }

  }

  /**
   * 查看当前登录用户
   *
   * @return
   */
  @GetMapping(value = "/loginData")
  @Operation(summary = "获取登录信息")
  public String loginData() {
    Subject subject = SecurityUtils.getSubject();
    String principal = (String) subject.getPrincipal();
    SysUser sysUser = JSONObject.parseObject(principal,
        SysUser.class);
    return new ResultMsg<String>().setCode(ResultState.SUCCESS).setData(
        JSONObject.toJSONString(SysUserRes.from(sysUser))).toJSON();
  }

  @GetMapping(value = "/loginOut")
  @Operation(summary = "登出")
  public String loginOut() {
    Subject subject = SecurityUtils.getSubject();
    subject.logout();
    return new ResultMsg<String>().setCode(ResultState.SUCCESS).toJSON();
  }

  @PostMapping(value = "fail")
  public String fail() {
    return "login fail";
  }
}