package com.ghjg.pd.controller.ref;


import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.toolkit.CollectionUtils;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.ghjg.pd.controller.BaseController;
import com.ghjg.pd.controller.model.req.ref.RefDepartmentReq;
import com.ghjg.pd.controller.model.res.ref.RefDepartmentRes;
import com.ghjg.pd.entity.ref.RefDepartment;
import com.ghjg.pd.service.ref.RefDepartmentService;
import com.ghjg.pd.uitll.CommonTools;
import com.ghjg.pd.uitll.ReturnMsg;
import com.ghjg.pd.uitll.TokenUtil;
import com.ghjg.pd.vo.RefDepartmentVo;
import com.shanghaigeography.Util.DateUtils;
import com.shanghaigeography.entity.ResultMsg;
import com.shanghaigeography.eum.ResultState;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.Parameter;
import io.swagger.v3.oas.annotations.tags.Tag;
import java.util.Date;
import java.util.List;
import java.util.Map;
import java.util.Objects;
import javax.annotation.Resource;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

/**
 * <p>
 * 部门科室表 前端控制器
 * </p>
 *
 * @author zk
 * @since 2024-01-04
 */
@RestController
@RequestMapping("/fortrans/refDepartment")
@Tag(name = "部门管理", description = "刘澳港")
public class RefDepartmentController extends BaseController {

  @Resource
  private RefDepartmentService refDepartmentService;

  @PostMapping("/saveOrUpdate")
  @Operation(summary = "新增或修改部门")
  public String saveOrUpdateDepartment(@RequestBody RefDepartmentReq req) {
    try {
      RefDepartment refDepartment = RefDepartment.from(req);
      if (Objects.isNull(refDepartment.getDepartmentId())) {
        // 新增
        Integer id = refDepartmentService.getIdFromSeq();
        refDepartment.setDepartmentId(id);
        refDepartment.setCreateTime(new Date());
        // todo 操作人员获取
//        sysUser.setCreateUser(TokenUtil.getLocalUser().getUserName());
        refDepartmentService.save(refDepartment);
      } else {
        // 修改
        refDepartment.setUpdateTime(new Date());
//        sysUser.setUpdateUser(TokenUtil.getLocalUser().getUserName());
        refDepartmentService.updateById(refDepartment);
      }
      //todo 授权相关操作
      return new ResultMsg<String>().setCode(ResultState.SUCCESS).setMsg("操作成功").setData(null)
          .toJSON();
    } catch (Exception e) {
      e.printStackTrace();
      return new ResultMsg<String>().setCode(ResultState.ERROR).setMsg("操作异常")
          .setData(e.getMessage()).toJSON();
    }
  }

  @DeleteMapping("/delete/{id}")
  @Operation(summary = "删除部门")
  public String deletePage(@PathVariable("id") String id) {
    try {
      RefDepartment refDepartment = refDepartmentService.getById(id);
      refDepartment.setDeleteFlag(1);
      refDepartment.setUpdateTime(new Date());
      refDepartment.setUpdateUser(TokenUtil.getLocalUser().getUserName());
      refDepartmentService.updateById(refDepartment);
      return new ResultMsg<String>().setCode(ResultState.SUCCESS).setMsg("删除成功").setData(null)
          .toJSON();
    } catch (Exception e) {
      return new ResultMsg<String>().setCode(ResultState.ERROR).setMsg("删除失败")
          .setData(e.getMessage())
          .toJSON();
    }
  }

  @PostMapping("/list")
  @Parameter(description = "current,size,departmentName,moduleName,pageName")
  @Operation(summary = "获取部门列表")
  public String getList(@RequestBody Map<String, Object> request) {
    int current = (int) request.get("current");
    List<RefDepartmentVo> list = refDepartmentService.getList(request);
    if (CollectionUtils.isEmpty(list)) {
      return new ResultMsg<String>().setCode(ResultState.ERROR_NEEDDATA).setMsg("暂无数据")
          .setData(null)
          .toJSON();
    }
    int count = CommonTools.getTotal(list);
    return ReturnMsg.returnMsgForList("_200",
        JSONArray.parseArray(
            JSONArray.toJSONStringWithDateFormat(list, DateUtils.DATE_FORMAT_19)),
        count, current);
  }


  @GetMapping("/detail/{id}")
  @Operation(summary = "获取部门信息")
  public String getRefDepartmentById(@PathVariable("id") String id) {
    try {
      RefDepartment one = refDepartmentService.getOne(
          Wrappers.<RefDepartment>lambdaQuery().eq(RefDepartment::getDepartmentId, id));
      return new ResultMsg<String>().setCode(ResultState.SUCCESS)
          .setData(JSONObject.toJSONString(RefDepartmentRes.from(one)))
          .toJSON();
    } catch (Exception e) {
      return new ResultMsg<String>().setCode(ResultState.ERROR_NEEDDATA).setMsg("暂无数据")
          .setData(e.getMessage())
          .toJSON();
    }
  }

}
