package com.ghjg.pd.controller.ref;


import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.toolkit.CollectionUtils;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.ghjg.pd.controller.BaseController;
import com.ghjg.pd.controller.model.req.ref.RefPositionReq;
import com.ghjg.pd.controller.model.res.ref.RefPositionRes;
import com.ghjg.pd.entity.ref.RefPosition;
import com.ghjg.pd.service.ref.RefPositionService;
import com.ghjg.pd.uitll.CommonTools;
import com.ghjg.pd.uitll.ReturnMsg;
import com.ghjg.pd.uitll.TokenUtil;
import com.shanghaigeography.Util.DateUtils;
import com.shanghaigeography.entity.ResultMsg;
import com.shanghaigeography.eum.ResultState;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.Parameter;
import io.swagger.v3.oas.annotations.tags.Tag;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.Map;
import java.util.Objects;
import javax.annotation.Resource;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;

/**
 * <p>
 * 职称表 前端控制器
 * </p>
 *
 * @author zk
 * @since 2024-01-04
 */
@Controller
@RequestMapping("/fortrans/refPosition")
@Tag(name = "职称管理", description = "刘澳港")
public class RefPositionController extends BaseController {

  @Resource
  RefPositionService refPositionService;

  @PostMapping("/saveOrUpdate")
  @Operation(summary = "新增或修改职称")
  public String saveOrUpdatePosition(@RequestBody RefPositionReq req) {
    try {
      RefPosition refPosition = RefPosition.from(req);
      if (Objects.isNull(refPosition.getPositionId())) {
        // 新增
        Integer id = refPositionService.getIdFromSeq();
        refPosition.setPositionId(id);
        refPosition.setCreateTime(new Date());
        // todo 操作人员获取
//        sysUser.setCreateUser(TokenUtil.getLocalUser().getUserName());
        refPositionService.save(refPosition);
      } else {
        // 修改
        refPosition.setUpdateTime(new Date());
//        sysUser.setUpdateUser(TokenUtil.getLocalUser().getUserName());
        refPositionService.updateById(refPosition);
      }
      //todo 授权相关操作
      return new ResultMsg<String>().setCode(ResultState.SUCCESS).setMsg("操作成功").setData(null)
          .toJSON();
    } catch (Exception e) {
      e.printStackTrace();
      return new ResultMsg<String>().setCode(ResultState.ERROR).setMsg("操作异常")
          .setData(e.getMessage()).toJSON();
    }
  }

  @DeleteMapping("/delete/{id}")
  @Operation(summary = "删除职位")
  public String deletePage(@PathVariable("id") String id) {
    try {
      RefPosition refPosition = refPositionService.getById(Integer.parseInt(id));
      refPosition.setDeleteFlag(1);
      refPosition.setUpdateTime(new Date());
      refPosition.setUpdateUser(TokenUtil.getLocalUser().getUserName());
      refPositionService.updateById(refPosition);
      return new ResultMsg<String>().setCode(ResultState.SUCCESS).setMsg("删除成功").setData(null)
          .toJSON();
    } catch (Exception e) {
      return new ResultMsg<String>().setCode(ResultState.ERROR).setMsg("删除失败")
          .setData(e.getMessage())
          .toJSON();
    }
  }

  @PostMapping("/list")
  @Parameter(description = "current,size")
  @Operation(summary = "获取职位列表")
  public String getList(@RequestBody Map<String, Object> request) {
    int current = (int) request.get("current");
    List<RefPosition> list = refPositionService.getList(request);
    if (CollectionUtils.isEmpty(list)) {
      return new ResultMsg<String>().setCode(ResultState.ERROR_NEEDDATA).setMsg("暂无数据")
          .setData(null)
          .toJSON();
    }
    List<RefPositionRes> resList = new ArrayList<>(list.size());
    list.forEach(x -> {
      RefPositionRes from = RefPositionRes.from(x);
      resList.add(from);
    });
    int count = CommonTools.getTotal(list);
    return ReturnMsg.returnMsgForList("_200",
        JSONArray.parseArray(
            JSONArray.toJSONStringWithDateFormat(resList, DateUtils.DATE_FORMAT_19)),
        count, current);
  }


  @GetMapping("/detail/{id}")
  @Operation(summary = "获取部门信息")
  public String getRefDepartmentById(@PathVariable("id") String id) {
    try {
      RefPosition one = refPositionService.getOne(
          Wrappers.<RefPosition>lambdaQuery().eq(RefPosition::getPositionId, Integer.parseInt(id)));
      return new ResultMsg<String>().setCode(ResultState.SUCCESS)
          .setData(JSONObject.toJSONString(RefPositionRes.from(one)))
          .toJSON();
    } catch (Exception e) {
      return new ResultMsg<String>().setCode(ResultState.ERROR_NEEDDATA).setMsg("暂无数据")
          .setData(e.getMessage())
          .toJSON();
    }
  }
}
