package com.ghjg.pd.controller.sys;


import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.toolkit.CollectionUtils;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.ghjg.pd.config.SnowflakeMakeConf;
import com.ghjg.pd.controller.BaseController;
import com.ghjg.pd.controller.model.req.sys.SysPageReq;
import com.ghjg.pd.controller.model.res.sys.SysPageRes;
import com.ghjg.pd.entity.sys.SysPage;
import com.ghjg.pd.service.sys.SysPageService;
import com.ghjg.pd.uitll.CommonTools;
import com.ghjg.pd.uitll.ReturnMsg;
import com.ghjg.pd.uitll.TokenUtil;
import com.shanghaigeography.Util.DateUtils;
import com.shanghaigeography.entity.ResultMsg;
import com.shanghaigeography.eum.ResultState;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.Parameter;
import io.swagger.v3.oas.annotations.tags.Tag;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.Map;
import java.util.Objects;
import javax.annotation.Resource;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

/**
 * <p>
 * 系统页面表 前端控制器
 * </p>
 *
 * @author zk
 * @since 2024-01-04
 */
@RestController
@RequestMapping("/fortrans/sysPage")
@Tag(name = "页面管理", description = "刘澳港")
public class SysPageController extends BaseController {

  @Resource
  SysPageService sysPageService;
  @Resource
  SnowflakeMakeConf snowflakeMakeConf;

  @PostMapping("/saveOrUpdate")
  @Operation(summary = "新增或修改页面")
  public String saveOrUpdatePage(@RequestBody SysPageReq req) {
    try {
      SysPage sysPage = SysPage.from(req);
      if (Objects.isNull(sysPage.getPageId())) {
        // 新增
        long id = snowflakeMakeConf.snowflakeId();
        sysPage.setPageId(String.valueOf(id));
        sysPage.setCreateTime(new Date());
        // todo 操作人员获取
//        sysUser.setCreateUser(TokenUtil.getLocalUser().getUserName());
        sysPageService.save(sysPage);
      } else {
        // 修改
        sysPage.setUpdateTime(new Date());
//        sysUser.setUpdateUser(TokenUtil.getLocalUser().getUserName());
        sysPageService.updateById(sysPage);
      }
      //todo 授权相关操作
      return new ResultMsg<String>().setCode(ResultState.SUCCESS).setMsg("操作成功").setData(null)
          .toJSON();
    } catch (Exception e) {
      e.printStackTrace();
      return new ResultMsg<String>().setCode(ResultState.ERROR).setMsg("操作异常")
          .setData(e.getMessage()).toJSON();
    }
  }

  @DeleteMapping("/delete/{id}")
  @Operation(summary = "删除页面")
  public String deletePage(@PathVariable("id") String id) {
    try {
      SysPage sysPage = sysPageService.getById(id);
      sysPage.setDeleteFlag(1);
      sysPage.setUpdateTime(new Date());
      sysPage.setUpdateUser(TokenUtil.getLocalUser().getUserName());
      sysPageService.updateById(sysPage);
      return new ResultMsg<String>().setCode(ResultState.SUCCESS).setMsg("删除成功").setData(null)
          .toJSON();
    } catch (Exception e) {
      return new ResultMsg<String>().setCode(ResultState.ERROR).setMsg("删除失败")
          .setData(e.getMessage())
          .toJSON();
    }
  }

  @PostMapping("/list")
  @Operation(summary = "获取页面列表")
  @Parameter(description = "current,size")
  public String getList(@RequestBody Map<String, Object> request) {
    int current = (int) request.get("current");
    List<SysPage> list = sysPageService.getList(request);
    if (CollectionUtils.isEmpty(list)) {
      return new ResultMsg<String>().setCode(ResultState.ERROR_NEEDDATA).setMsg("暂无数据")
          .setData(null)
          .toJSON();
    }
    int count = CommonTools.getTotal(list);
    List<SysPageRes> resList = new ArrayList<>(list.size());
    list.forEach(x -> {
      SysPageRes from = SysPageRes.from(x);
      resList.add(from);
    });
    return ReturnMsg.returnMsgForList("_200",
        JSONArray.parseArray(
            JSONArray.toJSONStringWithDateFormat(resList, DateUtils.DATE_FORMAT_19)),
        count, current);
  }


  @GetMapping("/detail/{id}")
  @Operation(summary = "获取页面信息")
  public String getSysPageById(@PathVariable("id") String id) {
    try {
      SysPage one = sysPageService.getOne(
          Wrappers.<SysPage>lambdaQuery().eq(SysPage::getPageId, id));
      return new ResultMsg<String>().setCode(ResultState.SUCCESS)
          .setData(JSONObject.toJSONString(SysPageRes.from(one)))
          .toJSON();
    } catch (Exception e) {
      return new ResultMsg<String>().setCode(ResultState.ERROR_NEEDDATA).setMsg("暂无数据")
          .setData(e.getMessage())
          .toJSON();
    }
  }

}
