package com.ghjg.pd.controller.sys;

import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.toolkit.CollectionUtils;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.ghjg.pd.config.SnowflakeMakeConf;
import com.ghjg.pd.controller.model.req.sys.SysPageModuleReq;
import com.ghjg.pd.controller.model.res.sys.SysPageModuleRes;
import com.ghjg.pd.entity.sys.SysPageModule;
import com.ghjg.pd.service.sys.SysPageModuleService;
import com.ghjg.pd.uitll.CommonTools;
import com.ghjg.pd.uitll.ReturnMsg;
import com.ghjg.pd.uitll.TokenUtil;
import com.shanghaigeography.Util.DateUtils;
import com.shanghaigeography.entity.ResultMsg;
import com.shanghaigeography.eum.ResultState;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.Parameter;
import io.swagger.v3.oas.annotations.tags.Tag;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.Map;
import java.util.Objects;
import javax.annotation.Resource;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

@RestController
@RequestMapping("/fortrans/sysPageMoudle")
@Tag(name = "页面模块管理", description = "刘澳港")
public class SysPageModuleController {

  @Resource
  SysPageModuleService sysPageModuleService;
  @Resource
  SnowflakeMakeConf snowflakeMakeConf;

  @PostMapping("/saveOrUpdate")
  @Operation(summary = "新增或修改页面模块")
  public String saveOrUpdatePageModule(@RequestBody SysPageModuleReq req) {
    try {
      SysPageModule sysPageModule = SysPageModule.from(req);
      if (Objects.isNull(sysPageModule.getModuleId())) {
        // 新增
        long id = snowflakeMakeConf.snowflakeId();
        sysPageModule.setModuleId(String.valueOf(id));
        sysPageModule.setCreateTime(new Date());
        // todo 操作人员获取
//        sysUser.setCreateUser(TokenUtil.getLocalUser().getUserName());
        sysPageModuleService.save(sysPageModule);
      } else {
        // 修改
        sysPageModule.setUpdateTime(new Date());
//        sysUser.setUpdateUser(TokenUtil.getLocalUser().getUserName());
        sysPageModuleService.updateById(sysPageModule);
      }
      //todo 授权相关操作
      return new ResultMsg<String>().setCode(ResultState.SUCCESS).setMsg("操作成功").setData(null)
          .toJSON();
    } catch (Exception e) {
      e.printStackTrace();
      return new ResultMsg<String>().setCode(ResultState.ERROR).setMsg("操作异常")
          .setData(e.getMessage()).toJSON();
    }
  }

  @DeleteMapping("/delete/{id}")
  @Operation(summary = "删除页面模块")
  public String deletePageModule(@PathVariable("id") String id) {
    try {
      SysPageModule sysPageModule = sysPageModuleService.getById(id);
      sysPageModule.setDeleteFlag(1);
      sysPageModule.setUpdateTime(new Date());
      sysPageModule.setUpdateUser(TokenUtil.getLocalUser().getUserName());
      sysPageModuleService.updateById(sysPageModule);
      return new ResultMsg<String>().setCode(ResultState.SUCCESS).setMsg("删除成功").setData(null)
          .toJSON();
    } catch (Exception e) {
      return new ResultMsg<String>().setCode(ResultState.ERROR).setMsg("删除失败")
          .setData(e.getMessage())
          .toJSON();
    }
  }

  @PostMapping("/list")
  @Operation(summary = "获取页面模块列表")
  @Parameter(description = "current,size")
  public String getList(@RequestBody Map<String, Object> request) {
    int current = (int) request.get("current");
    List<SysPageModule> list = sysPageModuleService.getList(request);
    if (CollectionUtils.isEmpty(list)) {
      return new ResultMsg<String>().setCode(ResultState.ERROR_NEEDDATA).setMsg("暂无数据")
          .setData(null)
          .toJSON();
    }
    int count = CommonTools.getTotal(list);
    List<SysPageModuleRes> resList = new ArrayList<>(list.size());
    list.forEach(x -> {
      SysPageModuleRes from = SysPageModuleRes.from(x);
      resList.add(from);
    });
    return ReturnMsg.returnMsgForList("_200",
        JSONArray.parseArray(
            JSONArray.toJSONStringWithDateFormat(resList, DateUtils.DATE_FORMAT_19)),
        count, current);
  }


  @GetMapping("/detail/{id}")
  @Operation(summary = "获取页面信息")
  public String getSysPageModuleById(@PathVariable("id") String id) {
    try {
      SysPageModule one = sysPageModuleService.getOne(
          Wrappers.<SysPageModule>lambdaQuery().eq(SysPageModule::getModuleId, id));
      return new ResultMsg<String>().setCode(ResultState.SUCCESS)
          .setData(JSONObject.toJSONString(SysPageModuleRes.from(one)))
          .toJSON();
    } catch (Exception e) {
      return new ResultMsg<String>().setCode(ResultState.ERROR_NEEDDATA).setMsg("暂无数据")
          .setData(e.getMessage())
          .toJSON();
    }
  }

}
