package com.ghjg.pd.controller.sys;


import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.toolkit.CollectionUtils;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.ghjg.pd.config.SnowflakeMakeConf;
import com.ghjg.pd.controller.BaseController;
import com.ghjg.pd.controller.model.req.sys.SysRoleReq;
import com.ghjg.pd.controller.model.res.sys.SysRoleRes;
import com.ghjg.pd.entity.sys.SysRole;
import com.ghjg.pd.service.sys.SysRoleService;
import com.ghjg.pd.uitll.CommonTools;
import com.ghjg.pd.uitll.ReturnMsg;
import com.ghjg.pd.uitll.TokenUtil;
import com.shanghaigeography.Util.DateUtils;
import com.shanghaigeography.entity.ResultMsg;
import com.shanghaigeography.eum.ResultState;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.Parameter;
import io.swagger.v3.oas.annotations.tags.Tag;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.Map;
import java.util.Objects;
import javax.annotation.Resource;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

/**
 * <p>
 * 用户角色表 前端控制器
 * </p>
 *
 * @author zk
 * @since 2024-01-04
 */
@RestController
@RequestMapping("/fortrans/sysRole")
@Tag(name = "角色管理", description = "刘澳港")
public class SysRoleController extends BaseController {

  @Resource
  SysRoleService sysRoleService;

  @Resource
  SnowflakeMakeConf snowflakeMakeConf;

  @PostMapping("/saveOrUpdate")
  @Operation(summary = "新增或修改角色")
  public String saveOrUpdateRole(@RequestBody SysRoleReq req) {
    try {
      SysRole sysRole = SysRole.from(req);
      if (Objects.isNull(sysRole.getRoleId())) {
        // 新增
        long id = snowflakeMakeConf.snowflakeId();
        sysRole.setRoleId(String.valueOf(id));
        sysRole.setCreateTime(new Date());
        // todo 操作人员获取
//        sysUser.setCreateUser(TokenUtil.getLocalUser().getUserName());
        sysRoleService.save(sysRole);
      } else {
        // 修改
        sysRole.setUpdateTime(new Date());
//        sysUser.setUpdateUser(TokenUtil.getLocalUser().getUserName());
        sysRoleService.updateById(sysRole);
      }
      //todo 授权相关操作
      return new ResultMsg<String>().setCode(ResultState.SUCCESS).setMsg("操作成功").setData(null)
          .toJSON();
    } catch (Exception e) {
      e.printStackTrace();
      return new ResultMsg<String>().setCode(ResultState.ERROR).setMsg("操作异常")
          .setData(e.getMessage()).toJSON();
    }
  }

  @DeleteMapping("/delete/{id}")
  @Operation(summary = "删除角色")
  public String deleteRole(@PathVariable("id") String id) {
    try {
      SysRole sysRole = sysRoleService.getById(id);
      sysRole.setDeleteFlag(1);
      sysRole.setUpdateTime(new Date());
      sysRole.setUpdateUser(TokenUtil.getLocalUser().getUserName());
      sysRoleService.updateById(sysRole);
      return new ResultMsg<String>().setCode(ResultState.SUCCESS).setMsg("删除成功").setData(null)
          .toJSON();
    } catch (Exception e) {
      return new ResultMsg<String>().setCode(ResultState.ERROR).setMsg("删除失败")
          .setData(e.getMessage())
          .toJSON();
    }
  }

  @PostMapping("/list")
  @Operation(summary = "获取角色列表")
  @Parameter(description = "current,size")
  public String getList(@RequestBody Map<String, Object> request) {
    int current = (int) request.get("current");
    List<SysRole> list = sysRoleService.getList(request);
    if (CollectionUtils.isEmpty(list)) {
      return new ResultMsg<String>().setCode(ResultState.ERROR_NEEDDATA).setMsg("暂无数据")
          .setData(null)
          .toJSON();
    }
    int count = CommonTools.getTotal(list);
    List<SysRoleRes> resList = new ArrayList<>(list.size());
    list.forEach(x -> {
      SysRoleRes from = SysRoleRes.from(x);
      resList.add(from);
    });
    return ReturnMsg.returnMsgForList("_200",
        JSONArray.parseArray(
            JSONArray.toJSONStringWithDateFormat(resList, DateUtils.DATE_FORMAT_19)),
        count, current);
  }


  @GetMapping("/detail/{id}")
  @Operation(summary = "获取角色信息")
  public String getSysRoleById(@PathVariable("id") String id) {
    try {
      SysRole one = sysRoleService.getOne(
          Wrappers.<SysRole>lambdaQuery().eq(SysRole::getRoleId, id));
      return new ResultMsg<String>().setCode(ResultState.SUCCESS)
          .setData(JSONObject.toJSONString(SysRoleRes.from(one)))
          .toJSON();
    } catch (Exception e) {
      return new ResultMsg<String>().setCode(ResultState.ERROR_NEEDDATA).setMsg("暂无数据")
          .setData(e.getMessage())
          .toJSON();
    }
  }
}
