package com.ghjg.pd.controller.sys;


import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.toolkit.CollectionUtils;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.ghjg.pd.config.SnowflakeMakeConf;
import com.ghjg.pd.controller.BaseController;
import com.ghjg.pd.controller.model.req.sys.SysUserReq;
import com.ghjg.pd.controller.model.res.sys.SysUserRes;
import com.ghjg.pd.entity.sys.SysUser;
import com.ghjg.pd.service.sys.SysUserService;
import com.ghjg.pd.uitll.CommonTools;
import com.ghjg.pd.uitll.Encodes;
import com.ghjg.pd.uitll.ReturnMsg;
import com.ghjg.pd.uitll.TokenUtil;
import com.shanghaigeography.Util.DateUtils;
import com.shanghaigeography.entity.ResultMsg;
import com.shanghaigeography.eum.ResultState;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.Parameter;
import io.swagger.v3.oas.annotations.tags.Tag;
import java.nio.charset.StandardCharsets;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.Map;
import java.util.Objects;
import java.util.stream.Collectors;
import javax.annotation.Resource;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;


/**
 * <p>
 * 系统用户表（管理端） 前端控制器
 * </p>
 *
 * @author zk
 * @since 2024-01-04
 */
@RestController
@RequestMapping("/fortrans/sysUser")
@Tag(name = "用户管理", description = "刘澳港")
public class SysUserController extends BaseController {

  @Resource
  SysUserService sysUserService;

  @Resource
  SnowflakeMakeConf snowflakeMakeConf;

  @GetMapping("/detail/{id}")
  @Operation(summary = "获取用户信息")
  public String getUserById(@PathVariable("id") String id) {
    try {
      SysUser one = sysUserService.getOne(
          Wrappers.<SysUser>lambdaQuery().eq(SysUser::getUserId, id));
      basTo(one);
      return new ResultMsg<String>().setCode(ResultState.SUCCESS)
          .setData(JSONObject.toJSONString(SysUserRes.from(one)))
          .toJSON();
    } catch (Exception e) {
      return new ResultMsg<String>().setCode(ResultState.ERROR_NEEDDATA).setMsg("暂无数据")
          .setData(e.getMessage())
          .toJSON();
    }
  }


  @DeleteMapping("/delete/{id}")
  @Operation(summary = "删除用户")
  public String deleteUser(@PathVariable("id") String id) {
    try {
      SysUser sysUser = sysUserService.getById(id);
      sysUser.setDeleteFlag(1);
      sysUser.setUpdateTime(new Date());
      sysUser.setUpdateUser(TokenUtil.getLocalUser().getUserName());
      sysUserService.updateById(sysUser);
      return new ResultMsg<String>().setCode(ResultState.SUCCESS).setMsg("删除成功").setData(null)
          .toJSON();
    } catch (Exception e) {
      return new ResultMsg<String>().setCode(ResultState.ERROR).setMsg("删除失败")
          .setData(e.getMessage())
          .toJSON();
    }

  }


  @PostMapping("/saveOrUpdate")
  @Operation(summary = "新增或修改用户")
  public String saveOrUpdateUser(@RequestBody SysUserReq req) {
    try {
      SysUser sysUser = SysUser.fromReq(req);
      bas(sysUser);
      if (Objects.isNull(sysUser.getUserId())) {
        // 新增
        List<SysUser> userList = sysUserService.list(Wrappers.<SysUser>lambdaQuery()
            .eq(SysUser::getUserName, sysUser.getUserName()));
        if (!org.springframework.util.CollectionUtils.isEmpty(userList)) {
          return new ResultMsg<String>().setCode(ResultState.ERROR).setMsg("用户名已存在!")
              .setData(null).toJSON();
        }
        long id = snowflakeMakeConf.snowflakeId();
        sysUser.setUserId(String.valueOf(id));
        sysUser.setCreateTime(new Date());
        // todo 操作人员获取
//        sysUser.setCreateUser(TokenUtil.getLocalUser().getUserName());
        sysUserService.save(sysUser);
      } else {
        // 修改
        sysUser.setUpdateTime(new Date());
//        sysUser.setUpdateUser(TokenUtil.getLocalUser().getUserName());
        sysUserService.updateById(sysUser);
      }
      //todo 授权相关操作
      return new ResultMsg<String>().setCode(ResultState.SUCCESS).setMsg("操作成功").setData(null)
          .toJSON();
    } catch (Exception e) {
      e.printStackTrace();
      return new ResultMsg<String>().setCode(ResultState.ERROR).setMsg("操作异常")
          .setData(e.getMessage()).toJSON();
    }

  }


  @PostMapping("/list")
  @Operation(summary = "获取用户列表")
  @Parameter(description = "current,size,userName,departmentId,positionId,userStatus")
  public String getList(@RequestBody Map<String, Object> request) {
    int current = (int) request.get("current");
    List<SysUser> list = sysUserService.getList(request);
    if (CollectionUtils.isEmpty(list)) {
      return new ResultMsg<String>().setCode(ResultState.ERROR_NEEDDATA).setMsg("暂无数据")
          .setData(null)
          .toJSON();
    }
    int count = CommonTools.getTotal(list);
    List<SysUserRes> resList = new ArrayList<>(list.size());
    List<SysUser> afterList = list.stream().peek(this::basTo).collect(Collectors.toList());
    System.out.println(JSONObject.toJSON(afterList));
    afterList.forEach(x -> {
      SysUserRes from = SysUserRes.from(x);
      resList.add(from);
    });
    return ReturnMsg.returnMsgForList("_200",
        JSONArray.parseArray(
            JSONArray.toJSONStringWithDateFormat(resList, DateUtils.DATE_FORMAT_19)),
        count, current);
  }

  private void bas(SysUser sysUser) {
    if (!Objects.isNull(sysUser.getUserPassword())) {
      sysUser.setUserPassword(
          Encodes.encodeBase64(Encodes.aesEncrypt(sysUser.getUserPassword().getBytes(
                  StandardCharsets.UTF_8),
              Encodes.ENCODES_KEY.getBytes(),
              Encodes.ENCODES_KEY.getBytes())));
    }
    if (!Objects.isNull(sysUser.getUserMobile())) {
      sysUser.setUserMobile(
          Encodes.encodeBase64(Encodes.aesEncrypt(sysUser.getUserMobile().getBytes(
                  StandardCharsets.UTF_8),
              Encodes.ENCODES_KEY.getBytes(),
              Encodes.ENCODES_KEY.getBytes())));
    }
  }

  public void basTo(SysUser sysUser) {
    if (!Objects.isNull(sysUser.getUserPassword())) {
      sysUser.setUserPassword(new String(Encodes.aesDecrypt(
          Encodes.decodeBase64(sysUser.getUserPassword()),
          Encodes.ENCODES_KEY.getBytes(),
          Encodes.ENCODES_KEY.getBytes()), StandardCharsets.UTF_8));
    }

    if (!Objects.isNull(sysUser.getUserMobile())) {
      sysUser.setUserMobile(new String(Encodes.aesDecrypt(
          Encodes.decodeBase64(sysUser.getUserMobile()),
          Encodes.ENCODES_KEY.getBytes(),
          Encodes.ENCODES_KEY.getBytes()), StandardCharsets.UTF_8));
    }
  }
}
