package com.ghjg.pd.shiro;

import com.ghjg.pd.shiro.filter.ClientShiroThree;
import com.ghjg.pd.shiro.filter.StaticFileFilter;
import java.util.LinkedHashMap;
import java.util.Map;
import javax.servlet.Filter;
import lombok.extern.slf4j.Slf4j;
import org.apache.shiro.realm.Realm;
import org.apache.shiro.spring.web.ShiroFilterFactoryBean;
import org.apache.shiro.web.filter.authc.LogoutFilter;
import org.apache.shiro.web.mgt.DefaultWebSecurityManager;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
@Slf4j
@Configuration
public class ShiroConfig {
    //静态资源校验
    @Autowired
    StaticFileFilter staticFileFilter;
    //客户端校验
    @Autowired
    ClientShiroThree clientShiroThree;

    @Bean
    public Realm myRealm() {
      return new UserShiroRealm();
    }


    @Bean
    public DefaultWebSecurityManager securityManager() {
      DefaultWebSecurityManager manager = new DefaultWebSecurityManager();
      manager.setRealm(myRealm());
      return manager;
    }
    @Bean
    public ShiroFilterFactoryBean shiroFilterFactoryBean() {
      ShiroFilterFactoryBean filter = new ShiroFilterFactoryBean();
      filter.setSecurityManager(securityManager());

      //加入自定义的filter
         /* shiro内置过滤器,实现权限相关拦截
            常用过滤器:
            *  anon:无需认证(登录),就可访问
            *  logout:登出
            *  authc 必须认证才能访问
            *  user:如果使用了 remeber me 功能可以直接访问
            *  perms:该资源必须得到资源权限才能访问
            *  role:该资源必须得到角色权限才能访问
            *  port:拦截指定端口的访问路径,指定端口才能通过
            *  ssl:必须是https请求
          * */
      Map<String, Filter> filterMap = filter.getFilters();
      filterMap.put("client", clientShiroThree);

      filterMap.put("loginOut", new LogoutFilter());

        filterMap.put("file", staticFileFilter);

        filter.setFilters(filterMap);

      //定义相关路径,如果没登录，会调用登录，这个Url路径
//      filter.setLoginUrl("/login");
//      filter.setUnauthorizedUrl("/noAuthorize");

        //未授权跳转地址
      filter.setUnauthorizedUrl("/nn/noZK");
      //定义拦截路径,记得将静态资源也排除过滤
      /*进行权限的控制,必须使用LinkHashMap,shrio要按照顺序进行设置*/
      LinkedHashMap<String, String> authMap = new LinkedHashMap<>();
        //不过滤
         authMap.put("/login", "anon");
         //按照token过滤
         authMap.put("/ghjg/gpsinfoRealtime/hello", "client");

        //按照token过滤
        authMap.put("/ghjg/gpsinfoRealtime/hello", "client");

        authMap.put("/ghjg/gpsinfoRealtime/loginOut", "loginOut");


      //只执行授权校验逻辑 自动登录
        authMap.put("/ghjg/gpsinfoRealtime/hello1", "roles[admin]");


        authMap.put("/ghjg/gpsinfoRealtime/hello2", "anon");


      //自己的过滤方式
      authMap.put("/**", "file");
      filter.setFilterChainDefinitionMap(authMap);

      //配置完成
    log.info("---------------shirofactory创建成功");
      return filter;
    }

    /**
     * 是否需要开启通过注解来过滤权限
     * 开启Shiro的注解(如@RequiresRoles,@RequiresPermissions),需借助SpringAOP扫描使用Shiro注解的类,并在必要时进行安全逻辑验证
     * 配置以下两个bean(DefaultAdvisorAutoProxyCreator(可选)和AuthorizationAttributeSourceAdvisor)即可实现此功能
     * @return
     */
//    @Bean
//    @DependsOn({"lifecycleBeanPostProcessor"})
//    public DefaultAdvisorAutoProxyCreator advisorAutoProxyCreator() {
//        DefaultAdvisorAutoProxyCreator advisorAutoProxyCreator = new DefaultAdvisorAutoProxyCreator();
//        advisorAutoProxyCreator.setProxyTargetClass(true);
//        return advisorAutoProxyCreator;
//
//    }
}





