package com.ghjg.pd.shiro;
/**
 * 自定义reaml
 */

import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.toolkit.CollectionUtils;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;

import com.ghjg.pd.entity.sys.SysUser;
import com.ghjg.pd.service.sys.SysUserService;
import com.ghjg.pd.uitll.Encodes;
import java.nio.charset.StandardCharsets;
import java.util.Date;
import java.util.HashSet;
import java.util.List;
import java.util.Set;
import javax.annotation.Resource;
import lombok.SneakyThrows;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.apache.shiro.SecurityUtils;
import org.apache.shiro.authc.AuthenticationException;
import org.apache.shiro.authc.AuthenticationInfo;
import org.apache.shiro.authc.AuthenticationToken;
import org.apache.shiro.authc.SimpleAuthenticationInfo;
import org.apache.shiro.authc.UsernamePasswordToken;
import org.apache.shiro.authz.AuthorizationInfo;
import org.apache.shiro.authz.SimpleAuthorizationInfo;
import org.apache.shiro.realm.AuthorizingRealm;
import org.apache.shiro.subject.PrincipalCollection;
import org.apache.shiro.subject.Subject;
import org.springframework.stereotype.Component;

@Slf4j
@Component
public class UserShiroRealm extends AuthorizingRealm {

  @Resource
  SysUserService userService;

  /**
   * 执行认证逻辑
   * <p>
   * controller写登录逻辑时使用
   *
   * @param authenticationToken
   * @return
   * @throws AuthenticationException
   */
  @SneakyThrows
  @Override
  protected AuthenticationInfo doGetAuthenticationInfo(AuthenticationToken authenticationToken)
      throws AuthenticationException {
    log.info("===   执行认证逻辑验证");
    //获取用户的登录信息,参数转换成传入进来时的状态
    UsernamePasswordToken upToken = (UsernamePasswordToken) authenticationToken;
    String username = upToken.getUsername();

    log.info("===   1.验证用户登录的用户名是否存在：" + JSONObject.toJSONString(upToken));
    List<SysUser> userList = userService.list(Wrappers.<SysUser>lambdaQuery()
        .eq(SysUser::getUserName, username));

    if (CollectionUtils.isEmpty(userList)) {
      throw new AuthenticationException("用户不存在");
    }

    if (StringUtils.isNotBlank(username)) {
      if (StringUtils.isNotBlank(new String(upToken.getPassword()))) {
        log.info("开始校验密码");
        String inputPassword = new String(upToken.getPassword());
        String verifyPassword = Encodes.encodeBase64(Encodes.aesEncrypt(inputPassword.getBytes(
                StandardCharsets.UTF_8),
            Encodes.ENCODES_KEY.getBytes(),
            Encodes.ENCODES_KEY.getBytes()));
        SysUser sysUser = userList.get(0);
        if (verifyPassword.equals(sysUser.getUserPassword())) {
          sysUser.setUserLastLoginTime(new Date());
          userService.updateById(sysUser);
          return new SimpleAuthenticationInfo(JSONObject.toJSONString(sysUser), upToken.getPassword(), "");
        }
        {
          throw new AuthenticationException("账号密码错误,请重新输入");
        }
      }
      return new SimpleAuthenticationInfo(upToken.getUsername(), upToken.getPassword(), "");
    }
    //判断用户名
//    if (user == null && user.size()<=0)
//    {
    log.info("没有此用户");
    return null;
//    }
//      log.info("===   用户信息："+ username);
//判断密码
    //第一个参数:用户的实体信息,可以是username,也可以是数据表对应的用户的实体类对象,这个值必须是唯一的
    //第二个参数是从数据库中查到的用户的密码
    //第三个参数:realmName是当前reaml的name,调用父类的getName()方法即可,或者不写

//    return new SimpleAuthenticationInfo(user.get(0), user.get(0).getUserPassword(), "");

//      return new SimpleAuthenticationInfo(username, upToken.getPassword(), "");

//    如果是通过盐值来进行密码的验证,(盐值可以保证在数据库中的加密后密码不一样) 如下
//    在注册时输入的密码然后生成一个随机数作为盐值,然后通过盐值和MD5对密码加密,把加密后的密码和盐值存入数据库
//     String salt=UUID.randomUUID().toString();//生成一个随机数,然后变成字符串
//    		entity.setSalt(salt);
//    		//通过盐值对密码加密
//    		SimpleHash sHash=new SimpleHash("MD5",entity.getPassword(), salt);
//
//     ByteSource credentialsSalt=ByteSource.Util.bytes(user.getSalt());
//
//    第一个参数和上面第一个一样, 第二个是数据库中查出的盐值加密的密码,第三个是处理后的盐值(如上一行),
//     第四个数据就是realmname,这样 下面这个方法就会把传进来的密码,通过盐值加密后与数据库里的比较
//   登录进来的在UsernamePasswordToken中的密码就是用户传进来的,不是加密处理后的.
//     return  new SimpleAuthenticationInfo(Object principal, Object hashedCredentials,
//        ByteSource credentialsSalt,
//        String realmName)

  }

  /**
   * 只执行授权校验逻辑
   *
   * @param principalCollection
   * @return
   */
  @SneakyThrows
  @Override
  protected AuthorizationInfo doGetAuthorizationInfo(PrincipalCollection principalCollection) {
    log.info("===   2.执行授权校验逻辑");
    //获取当前登录用户
    Subject subject = SecurityUtils.getSubject();

//      BusinessUser user = (BusinessUser) subject.getPrincipal();
    //下面这一行也是获取当前对象
    //User user=(User) principalCollection.getPrimaryPrincipal()
    //通过用户id查角色id
//      LambdaQueryWrapper<BusinessAuthUser> lambdaQueryWrapper=new LambdaQueryWrapper();
//      lambdaQueryWrapper.eq(BusinessAuthUser::getUserCode,user.getId());
//     List<BusinessAuthUser> list=  userRolesMapper.selectList(lambdaQueryWrapper);
//     if (list!=null && list.size()>0) {
//         List<Long> roleIds = list.stream().filter(i->StringUtils.isNotBlank(i.getAuthCode().toString())).map(BusinessAuthUser::getAuthCode).collect(Collectors.toList());
////通过角色id查权限
//         LambdaQueryWrapper<BusinessAuthInfo> sysAuthInfoLa=new LambdaQueryWrapper();
//         sysAuthInfoLa.in(BusinessAuthInfo::getId,roleIds);
//        List<BusinessAuthInfo> roles= rolesMapper.selectList(sysAuthInfoLa);
//         if (roles == null || roles.size() == 0)
//             throw new AuthorizationException();
//         //将权限标识封装在set集合中
    log.info("===   用户所有权限：" + subject.getPrincipals().toString());
    Set<String> pSet = new HashSet<>();
    pSet.add("admin");

    //通过配置文件查找白名单的资源;
    /*Integer id = bmd.getUserid();
    if (id.equals(user.getId())) {
      List<Integer> R = bmd.getRoles();
      List<String> bmdpermissions = rolesMapper.findPermissions(R.toArray(array));

      for (String permission : bmdpermissions) {
        if (!StringUtils.isEmpty(permission)) {
          pSet.add(permission);
        }
      }
    }
*/
    //给资源进行授权
    SimpleAuthorizationInfo info = new SimpleAuthorizationInfo();
//         info.setStringPermissions(pSet);
//          authorizationCache.put(user.getUsername(),info);
    return info;
//     }
//     else {
//         throw new Exception("权限验证错误");
//     }
  }

}
