package com.ghjg.pd.shiro.filter;


import com.ghjg.pd.eum.shiro.SystemType;
import com.ghjg.pd.uitll.TokenUtil;
import com.shanghaigeography.entity.ResultMsg;
import com.shanghaigeography.eum.ResultState;
import javax.servlet.ServletRequest;
import javax.servlet.ServletResponse;
import javax.servlet.http.HttpServletRequest;
import lombok.SneakyThrows;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.apache.shiro.web.filter.authc.AuthenticationFilter;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Component;

@Component
@Slf4j
public class ClientShiroThree extends AuthenticationFilter {

    //获取前端请求的请求头
    private static final String tokenHeard = "token";

    //判断请求的内容是否需要本地过滤登录
    private static final String SYSTEM_TYPE = "systemType";

    @Value("${static.file.notPass}")
    private String staticNotPass;

    /**
     * 只有当isAccessAllowed为false为false时才会执行,所以可以理解为,不允许访问后要怎么告诉用户的方法
     * @param servletRequest
     * @param response1
     * @return
     * @throws Exception
     */
    @Override
    protected boolean onAccessDenied(ServletRequest servletRequest, ServletResponse response1) throws Exception {
//        HttpServletResponse response = (HttpServletResponse) response1;
//        HttpServletRequest request = (HttpServletRequest) servletRequest;
//        String ajax = request.getHeader("x-requested-with");
//        if (null==ajax) {
////            response.sendRedirect("/login");
//        }else {
//            response.setContentType("text/html;charset=utf-8");
//            response.getWriter().write(new ResultMsg<String>().setCode(ResultState.ERROR).setMsg("登录信息校验失败，请重新登录").toJSON());
//
//        }
        return false;
    }

//    @Autowired
//    SysLoginfoServiceImpl sysLoginfoService;

    @SneakyThrows
    @Override
    protected boolean isAccessAllowed(ServletRequest servletRequest, ServletResponse response, Object mappedValue) {
        HttpServletRequest request = (HttpServletRequest) servletRequest;
        response.setContentType("text/html;charset=utf-8");
        log.info("===         校验token      ===");
        Integer systemType = request.getIntHeader(SYSTEM_TYPE);

        log.info("===        业务类型:"+SystemType.get(systemType));

        String token = request.getHeader(tokenHeard);
        log.info("===         校验token:"+token);
        if (null==token){
            log.info("===   不允许通过");
            response.setContentType("text/html;charset=utf-8");
            response.getWriter().write(new ResultMsg<String>().setCode(ResultState.ERROR).setMsg("登录信息校验失败，请重新登录").toJSON());
            return false;
        }

        if(SystemType.QIYE.getTypeCode()==systemType) {

            log.info("================是企业端" + token);

            //验证token的真实性
            boolean isSuccess = checkToken(token);
            if (!isSuccess)
            {
                response.getWriter().write(new ResultMsg<String>().setCode(ResultState.ERROR).setMsg("登录信息校验失败，请重新登录").toJSON());
                return false;
            }
        }
        String url = request.getRequestURL().toString();
        log.info("请求地址：" + request.getRequestURL());
        if (StringUtils.isNotBlank(staticNotPass)) {
            log.info("===  静态资源会过滤的内容：" + staticNotPass);
            return checkUrl(url);
        }
        log.info("================  通过" );
        return true;
    }

    /**
     * 校验url是否包含不允许返回的内容
     * EG:   .xml,.png等
     * @param url
     * @return
     */
   boolean checkUrl(  String url){
        if (staticNotPass.contains(",")) {
            String[] suff = staticNotPass.split(",");
            for (int i = 0; i < suff.length; i++) {
                if (url.contains(suff[i])) {
                    return false;
                }
            }
        } else {
            if (url.contains(staticNotPass)) {
                return false;
            }
        }
        log.info("================  通过" );
        return  true;
    }



    /**
     * 校验token
     * @param token
     * @return
     */
    boolean checkToken(String token){
        if (StringUtils.isBlank(token)) {
            log.info("-------------------token为空");
            return false;
        }
        log.info("===   请求存在token:"+token);
        try {
            TokenUtil.getTokenBody(token);
        } catch (Exception e) {
            log.info("----------------token有问题");
            return false;
        }
        return true;
    }


}
