package com.ghjg.pd.uitll;

import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.alibaba.fastjson.serializer.SerializerFeature;
import com.ghjg.pd.exception.ExceptionEnum;
import com.github.pagehelper.PageInfo;
import com.google.common.collect.Maps;
import com.shanghaigeography.Util.DateUtils;
import com.shanghaigeography.entity.ResultMsg;
import com.shanghaigeography.eum.ResultState;
import java.util.List;
import java.util.Map;

/**
 * @author ：沈晔浩
 * @date ：Created in 2020/7/14 10:28
 * @description：接口返回封装
 */
public class ReturnMsg {

    /**
    * @Description: 列表数据返回
    * @Param: [enumName, jsonArray, totalRowcount, pageSize]
    * @return: java.lang.String
    * @Author: 沈晔浩
    * @Date: 2020/7/16
    */
    public static String returnMsgForList(String enumName,JSONArray jsonArray,int totalRowcount,int pageSize) {

        JSONObject jsonObject = new JSONObject();
        JSONObject data = new JSONObject();
        int pageCount = 0;
        if (pageSize != 0) {
            pageCount = totalRowcount % pageSize == 0 ? totalRowcount / pageSize : totalRowcount / pageSize + 1;
        }
        data.put("TotalRowCount", totalRowcount);
        data.put("PageCount", pageCount);
        data.put("Rows", jsonArray);
        jsonObject.put("data", data);
        jsonObject.put("status", "success");
        jsonObject.put("code", ExceptionEnum.valueOf(enumName).getCode());
        jsonObject.put("msg", ExceptionEnum.valueOf(enumName).getMessage());
        return JSONObject.toJSONString(jsonObject, SerializerFeature.WriteMapNullValue);
    }

    public static String listToMsg(List<?> list, ResultState code) {
        return new ResultMsg<String>().setCode(code).setData(JSONObject.toJSONStringWithDateFormat(list, DateUtils.DATE_FORMAT_19)).toJSON();
    }

    public static String mapToMsg(Map<?, ?> map, ResultState code) {
        return new ResultMsg<String>().setCode(code).setData(JSONObject.toJSONStringWithDateFormat(map, DateUtils.DATE_FORMAT_19)).toJSON();
    }

    public static String returnNullDatas() {
        JSONObject jsonObject = new JSONObject();
        jsonObject.put("data", null);
        jsonObject.put("status", "success");
        jsonObject.put("code", "200");
        jsonObject.put("msg", "未查到数据");
        return JSONObject.toJSONString(jsonObject, SerializerFeature.WriteMapNullValue);
    }

    public static String returnMsgPageList(String enumName, PageInfo pageInfo) {

        JSONObject jsonObject = new JSONObject();
        JSONObject data = new JSONObject();
        data.put("Rows",pageInfo);
        jsonObject.put("data",data);
        jsonObject.put("status","success");
        jsonObject.put("code", ExceptionEnum.valueOf(enumName).getCode());
        jsonObject.put("msg",ExceptionEnum.valueOf(enumName).getMessage());
        return JSONObject.toJSONString(jsonObject, SerializerFeature.WriteMapNullValue);
    }

    public static String returnMsgPageList(String enumName, List list){
        JSONObject jsonObject = new JSONObject();
        JSONObject data = new JSONObject();
        JSONArray jsonArray = new JSONArray();
        for (int i = 0;i < list.size(); i++){
            jsonArray.add(object2UpperCase(list.get(i)));
        }

        data.put("data",jsonArray);

        jsonObject.put("Result",data);

        jsonObject.put("status","success");
        jsonObject.put("msg", ExceptionEnum.valueOf(enumName).getMessage());
        jsonObject.put("count",list.size());
        //获得查询总条数
        jsonObject.put("total",new PageInfo<>(list).getTotal());
        return JSONObject.toJSONString(jsonObject, SerializerFeature.WriteMapNullValue);
    }

    public static String returnMapMsg(String enumName, Map map){
        JSONObject jsonObject = new JSONObject();
        JSONObject data = new JSONObject();
        data.put("Rows",map);
        jsonObject.put("data",data);
        jsonObject.put("status","success");
        jsonObject.put("code", ExceptionEnum.valueOf(enumName).getCode());
        jsonObject.put("msg",ExceptionEnum.valueOf(enumName).getMessage());
        return JSONObject.toJSONString(jsonObject, SerializerFeature.WriteMapNullValue);
    }


    /**
    * @Description: 错误代码返回
    * @Param: [enumName]
    * @return: java.lang.String
    * @Author: 沈晔浩
    * @Date: 2020/7/16
    */
    public static String returnSuccessOrFailMsg(String enumName,String status,String enumMsg){
        JSONObject jsonObject = new JSONObject();
        jsonObject.put("status",status);
        jsonObject.put("code", ExceptionEnum.valueOf(enumName).getCode());
        if (enumMsg!=null && enumMsg != ""){
            jsonObject.put("msg",enumMsg);
        }else{
            jsonObject.put("msg",ExceptionEnum.valueOf(enumName).getMessage());
        }
        return JSONObject.toJSONString(jsonObject, SerializerFeature.WriteMapNullValue);
    }

    public static String returnErrorMsg(String enumName){
        JSONObject jsonObject = new JSONObject();
        jsonObject.put("data",null);
        jsonObject.put("status","error");
        jsonObject.put("code", ExceptionEnum.valueOf(enumName).getCode());
        jsonObject.put("msg",ExceptionEnum.valueOf(enumName).getMessage());
        return JSONObject.toJSONString(jsonObject, SerializerFeature.WriteMapNullValue);
    }

    /**
    * @Description: 自定义错误返回
    * @Param: [msg]
    * @return: java.lang.String
    * @Author: 沈晔浩
    * @Date: 2020/7/16
    */
    public static String returnErrorMsgNew(String msg){
        JSONObject jsonObject = new JSONObject();
        jsonObject.put("data",null);
        jsonObject.put("status","error");
        jsonObject.put("code", "500");
        jsonObject.put("msg",msg);
        return JSONObject.toJSONString(jsonObject, SerializerFeature.WriteMapNullValue);
    }

    public static String returnMsgNew(String msg){
        JSONObject jsonObject = new JSONObject();
        jsonObject.put("data",null);
        jsonObject.put("status","false");
        jsonObject.put("code", "200");
        jsonObject.put("msg",msg);
        return JSONObject.toJSONString(jsonObject, SerializerFeature.WriteMapNullValue);
    }

    public static String returnOneMsg(Object obj){
        JSONObject jsonObject = new JSONObject();
        jsonObject.put("data",obj);
        jsonObject.put("status","success");
        jsonObject.put("code", "200");
        jsonObject.put("msg",ExceptionEnum.valueOf("_200").getMessage());
        return JSONObject.toJSONString(jsonObject, SerializerFeature.WriteMapNullValue);
    }

    /**
    * @Description: 返回结果键大写，值null处理
    * @Param: [entity]
    * @return: java.util.Map<java.lang.String,java.lang.Object>
    * @Author: 沈晔浩
    * @Date: 2020/7/16
    */
    public static Map<String,Object> object2UpperCase(Object entity){
        Map<String,Object> res = Maps.newHashMap();
        if (null==entity){
            return res;
        }
        //将对象的属性转化为大写
        Map<String,Object> map = (Map)JSONObject.toJSON(entity);
//         = JSON.pa(json,String.class,Object.class);
        if (null!=map && !map.isEmpty()){
            for(Map.Entry<String,Object> entry:map.entrySet()){
                /**
                 * TODO-关键在这里根据业务需要转大小写
                 */
                res.put(entry.getKey().toUpperCase(),entry.getValue()==""||entry.getValue()==null?"":entry.getValue());
            }
        }
        return res;
    }
}
